"use strict";
/*
 * Copyright 2020-2023 Delft University of Technology and SynTest contributors
 *
 * This file is part of SynTest Framework - SynTest Javascript.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Instrumenter = void 0;
const core_1 = require("@babel/core");
const Visitor_1 = require("./Visitor");
const ast_javascript_1 = require("@syntest/ast-javascript");
class Instrumenter {
    instrument(code, filename) {
        return __awaiter(this, void 0, void 0, function* () {
            const options = JSON.parse(JSON.stringify(ast_javascript_1.defaultBabelOptions));
            let output = {};
            options.filename = filename;
            options.plugins.push([
                ({ types }) => {
                    const ee = new Visitor_1.Visitor(types, filename, {
                        coverageVariable: "__coverage__",
                        // reportLogic: opts.reportLogic,
                        // coverageGlobalScope: opts.coverageGlobalScope,
                        // coverageGlobalScopeFunc: opts.coverageGlobalScopeFunc,
                        ignoreClassMethods: [],
                        // inputSourceMap
                    });
                    return {
                        visitor: {
                            Program: {
                                enter: (path) => ee.enter(path),
                                exit(path) {
                                    output = ee.exit(path);
                                },
                            },
                        },
                    };
                },
            ]);
            const codeMap = yield (0, core_1.transformSync)(code, options);
            if (!output || !output.fileCoverage) {
                return code;
            }
            return codeMap.code;
        });
    }
}
exports.Instrumenter = Instrumenter;
//# sourceMappingURL=Instrumenter.js.map